netapp_ontap.models.fpolicy_policies API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_policies`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyPoliciesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyPolicies object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allow_privileged_access: bool GET PATCH`

    Specifies whether privileged access is required for FPolicy servers. Privileged access is used when the FPolicy server requires direct access to the cluster nodes. When this parameter is set to true, FPolicy servers can access files on the cluster using a separate data channel with privileged access.

  `enabled: bool GET PATCH`

    Specifies if the policy is enabled on the SVM or not. If no value is mentioned for this field but priority is set, then this policy will be enabled.

  `engine: FpolicyEngine GET POST PATCH`

    The engine field of the fpolicy_policies.

  `events: List[FpolicyEvent] GET POST PATCH`

    The events field of the fpolicy_policies.

    Example: ["event_cifs","event_open"]

  `mandatory: bool GET POST PATCH`

    Specifies what action to take on a file access event in a case when all primary and secondary servers are down or no response is received from the FPolicy servers within a given timeout period. When this parameter is set to true, file access events will be denied under these circumstances.

  `name: str GET POST`

    Specifies the name of the policy.

    Example: fp_policy_1

  `passthrough_read: bool GET POST PATCH`

    Specifies whether passthrough-read should be allowed for FPolicy servers registered for the policy. Passthrough-read is a way to read data for offline files without restoring the files to primary storage. Offline files are files that have been moved to secondary storage.

  `persistent_store: str GET POST PATCH`

    Specifies the persistent storage name. This can then be used to enable persistent mode for FPolicy events.

    Example: ps1

  `priority: Size GET POST PATCH`

    Specifies the priority that is assigned to this policy.

    Example: 1

  `privileged_user: str GET POST PATCH`

    Specifies the privileged user name for accessing files on the cluster using a separate data channel with privileged access. The input for this field should be in "domain\username" format.

    Example: mydomain\testuser

  `scope: FpolicyPoliciesScope GET POST PATCH`

    The scope field of the fpolicy_policies.